function GenExperiment(NumberOf5SecondSegmentsToAnalize_I,randomSelection,inputFile,outputDir)
    %GenExperiment(NumberOf5SecondSegmentsToAnalize_I,randomSelection,inputFile,outputDir)
    %
    %NumberOf5SecondSegmentsToAnalize_I: Use 1 to analyze a segment of 5
    %seconds, use 2 to analyze a segment of 10 seconds and so on.
    %Use the value 2 to use the current torch script configuration
    %
    %RandomSelection: Set True to randomize the selection of the data during the cross-validation
    %
    %InputFile: contains all the data ganerated by our ActiveMiles app.     
    %An example of the format used for this file is given in "AllFiles.txt"
    %All the data collected from our app can be downloaded at the following link:
    %http://hamlyn.doc.ic.ac.uk/activemiles/datasets.html
    %
    %OutputDir: folder where the output files are saved. This folder is used later by the torch script.    
    %Use the folder name "Data" to use the current torch script configuration
    %Once the matlab results are generated the torch script need to be executed.
    %You need the torch library installed in your system http://torch.ch/
    %run "src/runall1.sh 7" to train and obtain the classification results 
    
    global LabelCorr;
    global BigDataFile;
    global NumberOfSampleForSection;
    global NumberOf5SecondSegmentsToAnalize
    global FolderResults
    global numberOfCrossValidation

    BigDataFile=inputFile;
    FolderResults=outputDir;
    NumberOfSampleForSection=150;
    numberOfCrossValidation=10;
    NumberOf5SecondSegmentsToAnalize=NumberOf5SecondSegmentsToAnalize_I;

    mkdir(FolderResults);
    LabelCorr= initialization();
    ActiveMiles(randomSelection);

end



function ActiveMiles(randomSelection)
    global LabelCorr;
    global BigDataFile;
    global NumberOfSampleForSection;

    global NumberOf5SecondSegmentsToAnalize

    spectrogramSizeTime=10;
    spectrogramSizeFrequenz=54;
    currLabel=['Comb-',num2str(randomSelection),'Rnd-',num2str(NumberOf5SecondSegmentsToAnalize*5),'Sec'];
    [data,sizeSpect]=GenerateFeaturesComb(BigDataFile,LabelCorr,NumberOfSampleForSection,NumberOf5SecondSegmentsToAnalize,spectrogramSizeTime,spectrogramSizeFrequenz);
    saveData(data,randomSelection,currLabel,sizeSpect)  ;
    saveData(data,randomSelection,currLabel);
end


function [test,train,trainLabel,testLabel]=saveData(data,randomSelection,currLabel,otherInfo)
    global LabelCorr;
    global FolderResults
    global numberOfCrossValidation
    disp(['Saving data for ',currLabel])
    data((isnan(data(:,:))))=0;
    if (randomSelection)
        permutation=randperm(size(data,1));
        data=data(permutation,:);
    end

    allLabel=data(:,end);
    data=data(:,1:end-1);

    percOfTest=1/numberOfCrossValidation;
    for j=1:numberOfCrossValidation
        test=[];
        train=[];
        trainLabel=[];
        testLabel=[];
        for z=1:size(LabelCorr,2)
            i=z;
            %i=LabelCorr(z); %skoda %dfog
            indexofCurrentClass=find(allLabel==i);
            dataInclass=data(indexofCurrentClass,:);
            curSelectiveMaskForTest=zeros(1,size(dataInclass,1));
            curSelectiveMaskForTest(floor((j-1)*percOfTest*size(dataInclass,1)+1):floor(j*percOfTest*size(dataInclass,1)))=1;
            newTrain=dataInclass(not(curSelectiveMaskForTest),:);
            newTest=dataInclass(logical(curSelectiveMaskForTest),:);
            test=[test;newTest];
            train=[train;newTrain];
            trainLabel=[trainLabel,zeros(1,size(newTrain,1))+z];
            testLabel=[testLabel,zeros(1,size(newTest,1))+z];
        end
        fileID = fopen([FolderResults,'\train-',currLabel,'-cs',num2str(j),'.txt'],'w');
        fprintf(fileID,'%.8f ',train');

        fclose(fileID);
        fileID = fopen([FolderResults,'\test-',currLabel,'-cs',num2str(j),'.txt'],'w');
        fprintf(fileID,'%.8f ',test');

        fclose(fileID);
        fileID = fopen([FolderResults,'\testLabel-',currLabel,'-cs',num2str(j),'.txt'],'w');
        fprintf(fileID,'%.8f ',testLabel');
        fclose(fileID);
        fileID = fopen([FolderResults,'\trainLabel-',currLabel,'-cs',num2str(j),'.txt'],'w');
        fprintf(fileID,'%.8f ',trainLabel');
        fclose(fileID);
        save([FolderResults,'\train-',currLabel,'-cs',num2str(j)],'train','-v7.3');
        save([FolderResults,'\test-',currLabel,'-cs',num2str(j)],'test','-v7.3');
        fileID = fopen([FolderResults,'\MetaData-',currLabel,'-cs',num2str(j),'.txt'],'w');
        fprintf(fileID,'%.8f ',size(test));
        fprintf(fileID,'%.8f ',size(train));
        if nargin==4
            fprintf(fileID,'%.8f ',otherInfo);
        end
        fclose(fileID);
    end
end


function LabelCorr=initialization()
    LabelCorr(1)={'Running'};
    LabelCorr(2)={'Walking'};
    LabelCorr(3)={'Cycling'};
    LabelCorr(4)={'Casual Movement'};
    LabelCorr(5)={'Public Transport'};
    LabelCorr(6)={'No Activity'};
    LabelCorr(7)={'Reading Book'};
    LabelCorr(8)={'Up Stairs'};
    LabelCorr(9)={'Down Stairs'};
    LabelCorr(10)={'Jumping'};
    LabelCorr(11)={'Rowing'};
    LabelCorr(12)={'Eating'};
    LabelCorr(13)={'Social Interaction'};
end
